import functools
import logging
import signal


def handle_signal(server, ioloop, signum, frame):
    logging.info("Received signal {}; shutting down...".format(signum))

    def stop_ioloop():
        logging.info("Stopping IOLoop")
        ioloop.stop()

    def stop_server():
        logging.info("Stopping HTTPServer")
        server.stop()
        ioloop.call_later(2, stop_ioloop)

    ioloop.add_callback_from_signal(stop_server)


def on_sigterm(server, ioloop):
    signal.signal(signal.SIGTERM, functools.partial(handle_signal, server, ioloop))



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


setup(name="ustack-tornado-shutdown",
      version="0.1.0",
      description="Library for gracefully terminating a Tornado server on SIGTERM",
      url="https://github.com/ustudio/ustack-tornado-shutdown",
      packages=["ustack_tornado_shutdown"],
      install_requires=[])
